@@ -9,7 +9,7 @@
 #               2) http://homepage3.nifty.com/kamisaka/makernote/makernote_ricoh.htm
 #               3) Tim Gray private communication (GR)
 #               4) https://github.com/atotto/ricoh-theta-tools/
-#               5) Iliah Borg private communication (LibRaw)
+#               IB) Iliah Borg private communication (LibRaw)
 #------------------------------------------------------------------------------
 
 package Image::ExifTool::Ricoh;
@@ -143,7 +143,7 @@ my %ricohLensIDs = (
             9 => 'Warm White Fluorescent',
             10 => 'Manual',
             11 => 'Kelvin',
-            12 => 'Shade', #5
+            12 => 'Shade', #IB
         },
     }],
     0x1004 => { #3
@@ -1123,7 +1123,7 @@ interpret Ricoh maker notes EXIF meta information.
 
 =head1 AUTHOR
 
-Copyright 2003-2015, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2016, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
